#!/usr/bin/perl

#
# Copyright (C) 2021-2023 Joelle Maslak
# All Rights Reserved - See License
#

use Test2::V0 0.000111;

MAIN: {
    require App::RouterColorizer;
    ok(1);
    done_testing;
}

1;


